/*
 * main.cpp
 *
 * Copyright (C) 2008 Christophe Thommeret <hftom@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <KDebug>
#include <KAboutData>
#include <KLocalizedString>
#include <KUniqueApplication>
#include <KCmdLineArgs>
#include <KMainWindow>

#include <QMainWindow>
#include <QGLFormat>

#include "videowidget.h"



class MainWindow : public KMainWindow
{
public:
	MainWindow() {
		vw = new VideoWidget( this, QString() );
		setCentralWidget( vw );
		show();
	}
	static KCmdLineOptions cmdLineOptions() {
		return KCmdLineOptions();
	}

private:
	VideoWidget *vw;
};



class KaffeineGLApp : public KUniqueApplication
{
public:
	KaffeineGLApp() {}
	~KaffeineGLApp() {}

private:
	int newInstance() {
		KUniqueApplication::newInstance();
		return 0;
	}

	MainWindow mainWindow;
};



int main(int argc, char **argv)
{
	KAboutData aboutData("KaffeineGL", 0, ki18n("Kaffeine OpenGL Video Player"), "0.9-svn",
		ki18n("OpenGL Video Player for KDE4"),
		KAboutData::License_GPL_V2, ki18n("(C) 2008 hftom@free.fr"),
		KLocalizedString(), "http://kaffeine.kde.org");

	KCmdLineArgs::init(argc, argv, &aboutData);

	KApplication app;

	if ( !QGLFormat::hasOpenGL() ) {
		kError() << "This window system has no OpenGL support.";
		exit( 1 );
	}

	QString mrl;
	if ( argc>1 )
		mrl = argv[1];
	QMainWindow mainWindow;
	VideoWidget *vw = new VideoWidget( &mainWindow, mrl );
	mainWindow.setWindowTitle("KaffeineGL");
	mainWindow.setCentralWidget( vw );
	mainWindow.show();

	return app.exec();
}
